#!/bin/bash

set -e
set -o pipefail

while getopts 'd:t:' opt
do
	case $opt in
		d)
			db=$OPTARG
			;;
		t)
			team=$OPTARG
			;;
		?)
			exit 1
			;;
	esac
done

if [[ -z $db ]]
then
	echo "$0:" '-d is required' >&2
	exit 1
fi

if [[ -z $team ]]
then
	echo "$0:" '-t is required' >&2
	exit 1
fi

# grab most recently started live pk, if multiple
gamePk=$(mlblive schedule -t $team | jq '.dates[].games | map(select(.status.abstractGameState == "Live"))[-1].gamePk')
if [[ "$gamePk" = 'null' ]]
then
	echo "$0:" 'no live games found' >&2
	exit 1
fi

jqFilter='{gamePk} + (.gameData.teams | {awayTeam: .away.teamName, homeTeam: .home.teamName}) + (.liveData.plays.allPlays[] | (.result + (.about | {atBatIndex, halfInning, inning, isComplete, isScoringPlay, hasReview})))'

fmt='OFS=""; print $0, 0'
save="\"sqlite3 $db '.mode ascii' '.separator ' '.import /dev/stdin mlbdata'\""

# grab select data from each response with jq, add 0 to the end of each line
# (to go in the 'posted' db column), then write each line as they come in to db
mlblive subscribe -g $gamePk | jq -Sc "$jqFilter" | awk "{$fmt | $save; close($save)}"
